import {db} from "../service/database"

interface Grain {
    id: number;          // INTEGER PRIMARY KEY AUTOINCREMENT
    code: number;        // INTEGER NOT NULL
    no: number;          // INTEGER UNIQUE NOT NULL
    name: string;        // TEXT NOT NULL
    coef1?: number;      // REAL (可选)
    coef2?: number;      // REAL (可选)
    coef3?: number;      // REAL (可选)
    coef4?: number;      // REAL (可选)
    coef5?: number;      // REAL (可选)
    intercept?: number;  // REAL (可选)
    flag: number;        // INTEGER NOT NULL
}
// sqlite
const TableName = 'grain';

class GrainController {
    async queryGrainAll(): Promise<Grain[]> {
        const grainList: Grain[] = await db.findAll(TableName);
        return grainList;
    }

    async addGrain(info: Grain): Promise<number> {
        const add = await db.insert(TableName, info);
        return add;
    }

    async updateGrain(info: Grain): Promise<number> {
        const update = await db.update(TableName,'id = ?', info,  [info.id]);
        return update;
    }

    async delGrain(info: Grain): Promise<number> {
        const del = await db.delete(TableName, 'id = ?', [info.id]);
        return del;
    }
}

GrainController.toString = () => '[class GrainController]';

export default GrainController;
